/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import android.os.Parcelable
import kotlinx.android.parcel.Parcelize

/**
 * 선택한 사용자 정보 목록.
 * @property totalCount 선택한 전체 사용자 수. [SelectedUser]의 수와 다를 수 있음
 * @property users 실제 응답으로 전달되는 사용자 정보 목록
 */
@Parcelize
data class SelectedUsers(val totalCount: Int, val users: List<SelectedUser>?) : Parcelable

/**
 * 친구 선택 화면에서 사용자가 선택한 친구 정보입니다.
 *
 * @property id 친구의 회원번호, 앱과 연결된 친구에게만 존재
 *
 * @property uuid
 * 해당 앱에서의 사용자 식별 코드
 * 연결 상태와 관계 없으며 일반적으로 메시지 전송 시 사용
 * 카카오톡을 탈퇴하거나 새로 가입할 경우 값이 변경될 수 있음
 * 사용자의 계정 상태에 따라 바뀔 수 있으므로, 앱에서 사용자 식별자로 사용하는 것을 권장하지 않음
 *
 * @property profileNickname
 * 카카오톡 또는 카카오스토리의 프로필 닉네임
 * 동의 항목에 동의하지 않은 친구나 앱과 연결되지 않는 친구의 경우, 닉네임을 마스킹 처리하여 제공(닉네임 원본을 받으려면 권한 및 displayAllProfile 설정 필요)
 *
 * @property profileThumbnailImage
 * 카카오톡 또는 카카오스토리의 프로필 썸네일 이미지
 * 동의 항목에 동의하지 않은 친구나 앱과 연결되지 않은 친구의 경우, 프로필 이미지 미제공(프로필 이미지를 받으려면 권한 및 displayAllProfile 설정 필요)
 *
 * @property favorite 즐겨찾기 설정 여부
 */
@Parcelize
data class SelectedUser(
    val id: Long?,
    val uuid: String?,
    val profileNickname: String?,
    val profileThumbnailImage: String?,
    val favorite: Boolean?
) : Parcelable