/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.view

import android.content.pm.ActivityInfo
import android.os.Bundle
import android.os.Parcelable
import android.view.Window
import com.kakao.sdk.partner.friend.model.PickerChatRequestParams
import com.kakao.sdk.partner.friend.model.PickerOrientation
import com.kakao.sdk.partner.friend.model.ViewAppearance
import com.kakao.sdk.partner.friend.util.LayoutUtils
import com.kakao.sdk.v2.partner.friend.R

/**
 * @suppress
 */
internal class ChatPopupPickerActivity : PickerActivity() {
    override fun setViewAppearance(isPopup: Boolean, param: Parcelable) {
        if ((param as PickerChatRequestParams).viewAppearance == ViewAppearance.LIGHT) {
            setTheme(if (isPopup) R.style.DayOnlyPopup else R.style.DayOnlyFull)
        } else if (param.viewAppearance == ViewAppearance.DARK) {
            setTheme(if (isPopup) R.style.NightOnlyPopup else R.style.NightOnlyFull)
        }
    }

    override fun setViewOrientation(param: Parcelable) {
        if ((param as PickerChatRequestParams).orientation == PickerOrientation.PORTRAIT) {
            requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_SENSOR_PORTRAIT
        } else if (param.orientation == PickerOrientation.LANDSCAPE) {
            requestedOrientation = ActivityInfo.SCREEN_ORIENTATION_SENSOR_LANDSCAPE
        }
    }

    override fun setFragment() {
        supportFragmentManager.beginTransaction()
            .add(R.id.fragment_container, ChatPickerFragment()).commit()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        supportRequestWindowFeature(Window.FEATURE_NO_TITLE)
        setContentView(R.layout.kakao_sdk_activity_popup_picker)
        setPopupLayout()
    }

    private fun setPopupLayout() {
        window.attributes.apply {
            width = LayoutUtils.pickerWidth
            height = LayoutUtils.pickerHeight
            dimAmount = 0.5f
        }
    }
}