/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.view

import android.content.Context
import android.content.res.Configuration
import android.util.AttributeSet
import android.view.LayoutInflater
import android.view.View
import android.widget.ImageView
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import com.kakao.sdk.v2.partner.friend.R

/**
 * @suppress
 */
internal class EmptyView : ConstraintLayout {
    private lateinit var emptyImage: ImageView
    private lateinit var emptyMessage: TextView

    constructor(context: Context) : super(context)

    constructor(context: Context, attrs: AttributeSet) : super(context, attrs)

    constructor(context: Context, attrs: AttributeSet, defStyleAttr: Int) : super(
        context,
        attrs,
        defStyleAttr
    )

    init {
        initialize(context)
    }

    private fun initialize(context: Context) {
        val inflater = context.getSystemService(Context.LAYOUT_INFLATER_SERVICE) as LayoutInflater
        val view = inflater.inflate(R.layout.kakao_sdk_empty_friend_view, this, true)
        emptyImage = view.findViewById(R.id.empty_friend_image)
        emptyMessage = view.findViewById(R.id.empty_friend_text)

        val orientation = view.resources.configuration.orientation

        if (orientation != Configuration.ORIENTATION_PORTRAIT) {
            emptyImage.visibility = View.GONE
        }
    }

    fun setErrorMessage(message: String) {
        emptyMessage.text = message
    }
}